import React, { useMemo } from 'react';
import { Box, Flex, Heading, Spinner } from '@chakra-ui/react';
import { useTranslation } from 'react-i18next';
import { YMaps, Map, Placemark } from '@pbe/react-yandex-maps';
import { useLocation } from 'react-router-dom';

import { useGetOrdersQuery } from '../../__data__/service/api';
import getCoordinates from '../../utils/getCoordinates';

const OrdersMap = () => {
  const { t } = useTranslation('~', {
    keyPrefix: 'dry-wash.arm.map',
  });

  const location = useLocation();
  const params = new URLSearchParams(location.search);
  const latFromUrl = parseFloat(params.get('lat') || 55.78);
  const lonFromUrl = parseFloat(params.get('lon') || 49.12);
  const currentDate = useMemo(
    () =>
      params.get('currentDate')
        ? new Date(params.get('currentDate'))
        : new Date(),
    [],
  );

  const {
    data: ordersData,
    isLoading,
    isSuccess,
  } = useGetOrdersQuery({ date: currentDate });

  // Получаем координаты из location
  const orders = ordersData
    ?.map((order) => {
      const coords = getCoordinates(order.location);
      return coords ? { ...order, ...coords } : null;
    })
    .filter(Boolean);

  return (
    <Box p='8'>
      <Heading size='lg' mb='5'>
        {t('title')}
      </Heading>

      {isLoading && (
        <Flex justifyContent='center' alignItems='center'>
          <Spinner size='lg' />
        </Flex>
      )}

      {isSuccess && (
        <YMaps>
          <Map
            defaultState={{ center: [latFromUrl, lonFromUrl], zoom: 12 }}
            width='100%'
            height='70vh'
            modules={['geoObject.addon.balloon']}
          >
            {orders.map(({ id, lat, lon, carNumber, status }) => (
              <Placemark
                key={id}
                geometry={[lat, lon]}
                options={{
                  preset: 'islands#blueAutoIcon',
                  iconColor: 'blue',
                  balloonPanelMaxMapArea: 0,
                }}
                properties={{
                  balloonContent: `<strong>${t('carNumber')}</strong> ${carNumber}<br/><strong>${t('status')}</strong> ${status}`,
                }}
              />
            ))}
          </Map>
        </YMaps>
      )}
    </Box>
  );
};

export default OrdersMap;
